<?php

namespace Litecms\Career\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Litecms\Career\Models\Career;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Litecms\Career\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/career/career_job/*')) {
            Route::bind('career_job', function ($career_job) {
                $career_jobrepo = $this->app->make('Litecms\Career\Interfaces\CareerJobRepositoryInterface');
                return $career_jobrepo->findorNew($career_job);
            });
        }
        if (Request::is('*/career/career_resume/*')) {
            Route::bind('career_resume', function ($career_resume) {
                $career_resumerepo = $this->app->make('Litecms\Career\Interfaces\CareerResumeRepositoryInterface');
                return $career_resumerepo->findorNew($career_resume);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {
        if (request()->segment(1) == 'api' || request()->segment(2) == 'api') {
            return;
        }
        
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
            'prefix'     => trans_setlocale(),
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

}
